# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from .. import Provider as LoremProvider


class Provider(LoremProvider):
    word_connector = ''
    word_list = (
        u'一個',
        u'我們',
        u'時間',
        u'台灣',
        u'可以',
        u'公司',
        u'沒有',
        u'信息',
        u'下載',
        u'軟體',
        u'注冊',
        u'自己',
        u'產品',
        u'工作',
        u'論壇',
        u'企業',
        u'這個',
        u'他們',
        u'管理',
        u'已經',
        u'問題',
        u'內容',
        u'使用',
        u'進行',
        u'市場',
        u'服務',
        u'如果',
        u'系統',
        u'技術',
        u'發展',
        u'現在',
        u'作者',
        u'就是',
        u'網絡',
        u'提供',
        u'相關',
        u'我的',
        u'文章',
        u'方式',
        u'電話',
        u'發表',
        u'所有',
        u'時候',
        u'因為',
        u'台北',
        u'有限',
        u'公司',
        u'什麼',
        u'還是',
        u'開始',
        u'本站',
        u'發布',
        u'自己',
        u'支持',
        u'在線',
        u'國家',
        u'生活',
        u'聯系',
        u'積分',
        u'主題',
        u'所以',
        u'不能',
        u'的人',
        u'上海',
        u'中心',
        u'世界',
        u'游戲',
        u'需要',
        u'價格',
        u'用戶',
        u'通過',
        u'要求',
        u'不是',
        u'免費',
        u'個人',
        u'但是',
        u'地址',
        u'網站',
        u'情況',
        u'最后',
        u'設計',
        u'同時',
        u'這些',
        u'活動',
        u'手機',
        u'推薦',
        u'一些',
        u'主要',
        u'大家',
        u'發現',
        u'目前',
        u'文件',
        u'你的',
        u'不過',
        u'評論',
        u'生產',
        u'美國',
        u'圖片',
        u'經濟',
        u'功能',
        u'國際',
        u'的是',
        u'選擇',
        u'其他',
        u'這樣',
        u'會員',
        u'環境',
        u'來自',
        u'日期',
        u'成為',
        u'他的',
        u'最新',
        u'專業',
        u'一下',
        u'人員',
        u'任何',
        u'教育',
        u'資料',
        u'狀態',
        u'都是',
        u'點擊',
        u'為了',
        u'不會',
        u'出現',
        u'知道',
        u'社會',
        u'名稱',
        u'而且',
        u'介紹',
        u'音樂',
        u'等級',
        u'可能',
        u'這種',
        u'建設',
        u'朋友',
        u'雖然',
        u'電子',
        u'資源',
        u'看到',
        u'精華',
        u'電影',
        u'如何',
        u'新聞',
        u'閱讀',
        u'安全',
        u'全國',
        u'隻有',
        u'回復',
        u'大學',
        u'學生',
        u'學習',
        u'關於',
        u'項目',
        u'不同',
        u'以及',
        u'有關',
        u'那麼',
        u'開發',
        u'還有',
        u'隻是',
        u'非常',
        u'研究',
        u'廣告',
        u'首頁',
        u'方法',
        u'希望',
        u'地方',
        u'也是',
        u'單位',
        u'怎麼',
        u'應該',
        u'今天',
        u'以上',
        u'更新',
        u'帖子',
        u'顯示',
        u'能力',
        u'電腦',
        u'記者',
        u'查看',
        u'位置',
        u'不要',
        u'由於',
        u'無法',
        u'詳細',
        u'投資',
        u'是一',
        u'一般',
        u'進入',
        u'發生',
        u'這裡',
        u'感覺',
        u'更多',
        u'你們',
        u'的話',
        u'起來',
        u'標准',
        u'一樣',
        u'認為',
        u'女人',
        u'那個',
        u'設備',
        u'搜索',
        u'之后',
        u'然后',
        u'學校',
        u'銷售',
        u'組織',
        u'說明',
        u'提高',
        u'為什',
        u'作品',
        u'或者',
        u'喜歡',
        u'東西',
        u'方面',
        u'簡介',
        u'必須',
        u'經營',
        u'科技',
        u'作為',
        u'其中',
        u'運行',
        u'工程',
        u'解決',
        u'操作',
        u'經驗',
        u'地區',
        u'重要',
        u'直接',
        u'登錄',
        u'合作',
        u'結果',
        u'影響',
        u'這是',
        u'行業',
        u'對於',
        u'表示',
        u'程序',
        u'包括',
        u'留言',
        u'規定',
        u'處理',
        u'男人',
        u'各種',
        u'部門',
        u'數據',
        u'具有',
        u'商品',
        u'系列',
        u'大小',
        u'因此',
        u'關系',
        u'可是',
        u'比較',
        u'文化',
        u'一直',
        u'法律',
        u'這麼',
        u'您的',
        u'城市',
        u'分析',
        u'基本',
        u'最大',
        u'類別',
        u'兩個',
        u'日本',
        u'得到',
        u'一次',
        u'繼續',
        u'成功',
        u'她的',
        u'責任',
        u'深圳',
        u'業務',
        u'歡迎',
        u'加入',
        u'能夠',
        u'覺得',
        u'部分',
        u'中文',
        u'根據',
        u'人民',
        u'政府',
        u'控制',
        u'其實',
        u'之間',
        u'一種',
        u'威望',
        u'實現',
        u'語言',
        u'出來',
        u'謝謝',
        u'社區',
        u'品牌',
        u'是否',
        u'工具',
        u'完全',
        u'決定',
        u'很多',
        u'網上',
        u'事情',
        u'今年',
        u'國內',
        u'以后',
        u'制作',
        u'瀏覽',
        u'過程',
        u'完成',
        u'類型',
        u'來源',
        u'質量',
        u'有些',
        u'一起',
        u'當然',
        u'汽車',
        u'一點',
        u'幫助',
        u'增加',
        u'歷史',
        u'以下',
        u'不斷',
        u'應用',
        u'那些',
        u'密碼',
        u'計劃',
        u'如此',
        u'次數',
        u'到了',
        u'擁有',
        u'孩子',
        u'原因',
        u'參加',
        u'隻要',
        u'報告',
        u'當前',
        u'客戶',
        u'正在',
        u'注意',
        u'標題',
        u'空間',
        u'一定',
        u'一切',
        u'特別',
        u'全部',
        u'准備',
    )